PyJabber
======================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   readme
   installation
   usage
   webpage
   architecture
   contributing
   authors
   history
